pub struct ExecutionScopes {
    pub data: Vec<HashMap<String, Box<dyn Any>>>,
}

Fields

data: Vec<HashMap<String, Box<dyn Any>>>

Implementations

Returns a mutable reference to the dictionary containing the variables present in the current scope

Returns a dictionary containing the variables present in the current scope

Removes a variable from the current scope given its name

Creates or updates an existing variable given its name and boxed value

Returns the value in the current execution scope that matches the name and is of the given generic type

Returns a reference to the value in the current execution scope that matches the name and is of the given generic type

Returns a mutable reference to the value in the current execution scope that matches the name and is of the given generic type

Returns the value in the current execution scope that matches the name

Returns the value in the current execution scope that matches the name

Returns the value in the current execution scope that matches the name and is of type List

Returns a reference to the value in the current execution scope that matches the name and is of type List

Returns a mutable reference to the value in the current execution scope that matches the name and is of type List

Returns the value in the dict manager

Returns a mutable reference to the value in the current execution scope that matches the name and is of the given type

Inserts the boxed value into the current scope

Inserts the value into the current scope