pub enum MaybeRelocatable {
    RelocatableValue(Relocatable),
    Int(Felt),
}

Variants



RelocatableValue(Relocatable)



Int(Felt)

Implementations

Adds a Felt to self

Adds a usize to self

Adds a MaybeRelocatable to self Cant add two relocatable values

Substracts two MaybeRelocatable values and returns the result as a MaybeRelocatable value. Only values of the same type may be substracted. Relocatable values can only be substracted if they belong to the same segment.

Performs integer division and module on a MaybeRelocatable::Int by another MaybeRelocatable::Int and returns the quotient and reminder.