Struct cairo_vm::vm::trace::trace_entry::TraceEntry
source · pub struct TraceEntry {
pub pc: Relocatable,
pub ap: Relocatable,
pub fp: Relocatable,
}Expand description
A trace entry for every instruction that was executed. Holds the register values before the instruction was executed.
Fields
pc: Relocatableap: Relocatablefp: RelocatableTrait Implementations
sourceimpl Debug for TraceEntry
impl Debug for TraceEntry
sourceimpl PartialEq<TraceEntry> for TraceEntry
impl PartialEq<TraceEntry> for TraceEntry
sourcefn eq(&self, other: &TraceEntry) -> bool
fn eq(&self, other: &TraceEntry) -> bool
This method tests for
self and other values to be equal, and is used
by ==.impl Eq for TraceEntry
impl StructuralEq for TraceEntry
impl StructuralPartialEq for TraceEntry