pub struct Memory {
    pub data: Vec<Vec<Option<MaybeRelocatable>>>,
    pub temp_data: Vec<Vec<Option<MaybeRelocatable>>>,
    pub validated_addresses: HashSet<MaybeRelocatable>,
    /* private fields */
}

Fields

data: Vec<Vec<Option<MaybeRelocatable>>>temp_data: Vec<Vec<Option<MaybeRelocatable>>>validated_addresses: HashSet<MaybeRelocatable>

Implementations

Inserts an MaybeRelocatable value into an address given by a MaybeRelocatable::Relocatable Will panic if the segment index given by the address corresponds to a non-allocated segment If the address isnt contiguous with previously inserted data, memory gaps will be represented by inserting None values

Relocates the memory according to the relocation rules and clears self.relocaction_rules.

Applies validation_rules to the current memory