pub struct MemorySegmentManager {
    pub num_segments: usize,
    pub num_temp_segments: usize,
    pub segment_sizes: HashMap<usize, usize>,
    pub segment_used_sizes: Option<Vec<usize>>,
    pub public_memory_offsets: HashMap<usize, Vec<(usize, usize)>>,
}

Fields

num_segments: usizenum_temp_segments: usizesegment_sizes: HashMap<usize, usize>segment_used_sizes: Option<Vec<usize>>public_memory_offsets: HashMap<usize, Vec<(usize, usize)>>

Implementations

Adds a new segment and returns its starting location as a RelocatableValue.

Adds a new temporary segment and returns its starting location as a RelocatableValue. Negative segment_index indicates its refer to a temporary segment

Writes data into the memory at address ptr and returns the first address after the data.

Calculates the size (number of non-none elements) of each memory segment.

Returns the number of used segments when they are already computed. Returns None otherwise.

Returns a vector that contains the first relocated address of each memory segment