Module cairo_vm::hint_processor::hint_processor_utils
source · Functions
Computes the memory address of the ids variable indicated by the HintReference as a Relocatable
Tries to convert a Felt value to u32
Returns the Integer value stored in the given ids variable
Returns the Relocatable value stored in the given ids variable
Inserts value into the address of the given ids variable