Enum cairo_vm::types::relocatable::MaybeRelocatable
source · pub enum MaybeRelocatable {
RelocatableValue(Relocatable),
Int(Felt),
}Variants
RelocatableValue(Relocatable)
Int(Felt)
Implementations
sourceimpl MaybeRelocatable
impl MaybeRelocatable
sourcepub fn add_int(
&self,
other: &Felt
) -> Result<MaybeRelocatable, VirtualMachineError>
pub fn add_int(
&self,
other: &Felt
) -> Result<MaybeRelocatable, VirtualMachineError>
Adds a Felt to self
sourcepub fn add_usize(&self, other: usize) -> MaybeRelocatable
pub fn add_usize(&self, other: usize) -> MaybeRelocatable
Adds a usize to self
sourcepub fn add(
&self,
other: &MaybeRelocatable
) -> Result<MaybeRelocatable, VirtualMachineError>
pub fn add(
&self,
other: &MaybeRelocatable
) -> Result<MaybeRelocatable, VirtualMachineError>
Adds a MaybeRelocatable to self Cant add two relocatable values
sourcepub fn sub(
&self,
other: &MaybeRelocatable
) -> Result<MaybeRelocatable, VirtualMachineError>
pub fn sub(
&self,
other: &MaybeRelocatable
) -> Result<MaybeRelocatable, VirtualMachineError>
Substracts two MaybeRelocatable values and returns the result as a MaybeRelocatable value. Only values of the same type may be substracted. Relocatable values can only be substracted if they belong to the same segment.
sourcepub fn divmod(
&self,
other: &MaybeRelocatable
) -> Result<(MaybeRelocatable, MaybeRelocatable), VirtualMachineError>
pub fn divmod(
&self,
other: &MaybeRelocatable
) -> Result<(MaybeRelocatable, MaybeRelocatable), VirtualMachineError>
Performs integer division and module on a MaybeRelocatable::Int by another MaybeRelocatable::Int and returns the quotient and reminder.
pub fn get_int_ref(&self) -> Result<&Felt, VirtualMachineError>
pub fn get_relocatable(&self) -> Result<Relocatable, VirtualMachineError>