pub struct VirtualMachine { /* private fields */ }

Implementations

Compute operands and result, trying to deduce them if normal memory access returns a None value.

Makes sure that all assigned memory cells are consistent with their auto deduction rules.

Adds a new segment and to the VirtualMachine.memory returns its starting location as a RelocatableValue.

Gets the integer value corresponding to the Relocatable address

Gets the relocatable value corresponding to the Relocatable address

Gets a MaybeRelocatable value from memory indicated by a generic address

Returns a reference to the vector with all builtins present in the virtual machine

Inserts a value into a memory address given by a Relocatable value

Writes data into the memory at address ptr and returns the first address after the data.

Writes args into the memory at address ptr and returns the first address after the data. Perfroms modulo on each element

Gets n_ret return values from memory

Gets n elements from memory starting from addr (n being size)

Gets n elements from memory starting from addr (n being size)

Gets n integer values from memory starting from addr (n being size),

Add a new relocation rule.

Will return an error if any of the following conditions are not met:

  • Source address’s segment must be negative (temporary).
  • Source address’s offset must be zero.
  • There shouldn’t already be relocation at the source segment.

Proxy to MemorySegmentManager::compute_effective_sizes() to make it accessible from outside cairo-rs.